@@ -1,6 +1,6 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.2.5)
- * Copyright (C) 2022 The Jalview Authors
+ * Jalview - A Sequence Alignment Editor and Viewer (2.11.2.6)
+ * Copyright (C) 2023 The Jalview Authors
  * 
  * This file is part of Jalview.
  * 
@@ -1146,12 +1146,16 @@ public class Jalview
     System.setProperty("com.apple.mrj.application.apple.menu.about.name",
             ChannelProperties.getProperty("app_name"));
     System.setProperty("apple.laf.useScreenMenuBar", "true");
+    /*
+     * broken native LAFs on (ARM?) macbooks
     set = setQuaquaLookAndFeel();
     if ((!set) || !UIManager.getLookAndFeel().getClass().toString()
             .toLowerCase(Locale.ROOT).contains("quaqua"))
     {
       set = setVaquaLookAndFeel();
     }
+     */
+    set = setFlatLookAndFeel();
     return set;
   }
 
