@@ -1,6 +1,6 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.2.5)
- * Copyright (C) 2022 The Jalview Authors
+ * Jalview - A Sequence Alignment Editor and Viewer (2.11.2.6)
+ * Copyright (C) 2023 The Jalview Authors
  * 
  * This file is part of Jalview.
  * 
@@ -453,7 +453,10 @@ public class ThreeDBStructureChooserQuerySource
           pdbEntry.setRetrievalUrl(urlStr);
         }
         pdbEntry.setProvider(typeColumn);
-        pdbEntry.setProviderPage(modelPage);
+        if (modelPage != null)
+        {
+          pdbEntry.setProviderPage(modelPage);
+        }
         selectedSeq.getDatasetSequence().addPDBId(pdbEntry);
       }
       pdbEntriesToView[count++] = pdbEntry;
@@ -546,6 +549,11 @@ public class ThreeDBStructureChooserQuerySource
       try
       {
         resultList = pdbquery.executePDBFTSRestRequest(pdbRequest);
+        if (resultList.getNumberOfItemsFound() == 0)
+        {
+          Console.info("Unexpectedly returned no results for pdbe query: "
+                  + pdb_Query);
+        }
         results.add(resultList);
         lastPdbRequest = pdbRequest;
       } catch (Exception ex)
